@@ -1,8 +1,8 @@
 context("test-county_complete")
 
-test_that("rows and columns match old openintro data", {
+test_that("rows and columns match expected dimensions", {
   expect_equal(nrow(county_complete), 3142)
-  expect_equal(ncol(county_complete), 142)
+  expect_equal(ncol(county_complete), 188)
 })
 
 test_that("column names are lower case", {
